// Copyright 2022 ESRI
//
// All rights reserved under the copyright laws of the United States
// and applicable international laws, treaties, and conventions.
//
// You may freely redistribute and use this sample code, with or
// without modification, provided you include the original copyright
// notice and use restrictions.
//
// See the Sample code usage restrictions document for further information.
//

#include "Display_device_location.h"

#include "Map.h"
#include "MapTypes.h"
#include "MapQuickView.h"

#include "LocationDisplay.h"
#include "MapViewTypes.h"

using namespace Esri::ArcGISRuntime;

Display_device_location::Display_device_location(QObject* parent /* = nullptr */):
    QObject(parent),
    m_map(new Map(BasemapStyle::ArcGISStreets, this))
{
}

Display_device_location::~Display_device_location()
{
}

MapQuickView* Display_device_location::mapView() const
{
    return m_mapView;
}

void Display_device_location::startLocation()
{
    // start location display
    m_mapView->locationDisplay()->start();
    // center the location display around the device location
    m_mapView->locationDisplay()->setAutoPanMode(LocationDisplayAutoPanMode::Recenter);
}

// Set the view (created in QML)
void Display_device_location::setMapView(MapQuickView* mapView)
{
    if (!mapView || mapView == m_mapView)
    {
        return;
    }

    m_mapView = mapView;
    m_mapView->setMap(m_map);

    startLocation();

    emit mapViewChanged();
}

